"use strict";
/********************************************************************************
 * Copyright (C) 2021 Jon Radchenko and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var ServerProxyListWidget_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServerProxyListWidget = void 0;
require("../../styles/server-proxy-list.css");
const React = require("react");
const inversify_1 = require("inversify");
const browser_1 = require("@theia/core/lib/browser");
const server_proxy_instance_manager_1 = require("theia-server-proxy-extension/lib/browser/server-proxy-instance-manager");
const server_proxy_open_handler_1 = require("theia-server-proxy-extension/lib/browser/server-proxy-open-handler");
const window_service_1 = require("@theia/core/lib/browser/window/window-service");
const server_proxy_1 = require("theia-server-proxy-extension/lib/common/server-proxy");
const server_proxy_url_manager_1 = require("theia-server-proxy-extension/lib/common/server-proxy-url-manager");
let ServerProxyListWidget = ServerProxyListWidget_1 = class ServerProxyListWidget extends browser_1.ReactWidget {
    constructor() {
        super(...arguments);
        this.serverProxyInstances = [];
    }
    async init() {
        this.id = ServerProxyListWidget_1.ID;
        this.title.label = ServerProxyListWidget_1.LABEL;
        this.title.caption = ServerProxyListWidget_1.LABEL;
        this.title.closable = true;
        this.serverProxyInstances = await this.serverProxyInstanceManager.getInstances();
        this.update();
        this.toDispose.push(this.serverProxyInstanceManager.updated(async () => {
            this.serverProxyInstances = await this.serverProxyInstanceManager.getInstances();
            this.update();
        }));
    }
    async onOpen(instance) {
        await this.serverProxyOpenHandler.openInstance(instance);
    }
    render() {
        return (React.createElement("div", { className: "server-proxy-list" }, this.serverProxyInstances.map(instance => {
            return React.createElement(ServerProxyComponent, Object.assign({ key: instance.id }, {
                instance,
                onStop: () => instance.stop(),
                onOpen: () => this.onOpen(instance),
                onOpenBrowser: () => this.windowService.openNewWindow(this.serverProxyUrlManager.getPublicPath(instance.serverProxy, instance.id), { external: true })
            }));
        })));
    }
};
ServerProxyListWidget.ID = "server.proxy.debug.widget";
ServerProxyListWidget.LABEL = 'Server Proxy List';
__decorate([
    (0, inversify_1.inject)(server_proxy_instance_manager_1.ServerProxyInstanceManager),
    __metadata("design:type", server_proxy_instance_manager_1.ServerProxyInstanceManager)
], ServerProxyListWidget.prototype, "serverProxyInstanceManager", void 0);
__decorate([
    (0, inversify_1.inject)(window_service_1.WindowService),
    __metadata("design:type", Object)
], ServerProxyListWidget.prototype, "windowService", void 0);
__decorate([
    (0, inversify_1.inject)(server_proxy_open_handler_1.ServerProxyOpenHandler),
    __metadata("design:type", server_proxy_open_handler_1.ServerProxyOpenHandler)
], ServerProxyListWidget.prototype, "serverProxyOpenHandler", void 0);
__decorate([
    (0, inversify_1.inject)(server_proxy_url_manager_1.ServerProxyUrlManager),
    __metadata("design:type", server_proxy_url_manager_1.ServerProxyUrlManager)
], ServerProxyListWidget.prototype, "serverProxyUrlManager", void 0);
__decorate([
    (0, inversify_1.postConstruct)(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], ServerProxyListWidget.prototype, "init", null);
ServerProxyListWidget = ServerProxyListWidget_1 = __decorate([
    (0, inversify_1.injectable)()
], ServerProxyListWidget);
exports.ServerProxyListWidget = ServerProxyListWidget;
class ServerProxyComponent extends React.Component {
    getStatusClassName() {
        if (server_proxy_1.ServerProxyInstanceStatus.isRunning(this.props.instance.status)) {
            return "status-started";
        }
        else if (server_proxy_1.ServerProxyInstanceStatus.isCompleted(this.props.instance.status)) {
            return "status-stopped";
        }
        else {
            return "status-loading";
        }
    }
    render() {
        const instance = this.props.instance;
        const actions = [];
        actions.push(React.createElement("button", { className: "theia-button", key: "stop", onClick: this.props.onStop }, "Stop"));
        actions.push(React.createElement("button", { className: "theia-button", key: "open", onClick: this.props.onOpen }, "Open"));
        actions.push(React.createElement("button", { className: "theia-button", key: "open-browser", onClick: this.props.onOpenBrowser }, "Open in Browser"));
        const statusClassName = this.getStatusClassName();
        return React.createElement("div", { className: "row exposedPort", id: "port-" + instance.id, title: JSON.stringify(instance.context) },
            React.createElement("span", { className: "indicator" },
                React.createElement("i", { className: "fa " + statusClassName })),
            React.createElement("span", { className: "name" }, instance.serverProxy.name),
            React.createElement("span", { className: "name" },
                " \u2013 ",
                instance.status.statusId),
            React.createElement("span", { className: "actions" }, actions));
    }
}
//# sourceMappingURL=server-proxy-list-widget.js.map